"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlantUmlDiagramGenerator = void 0;
const plantuml_pipe_1 = require("plantuml-pipe");
const Queue = require("queue-fifo");
/**
 * Class for generating diagrams from PlantUML code.
 * This class can spawn multiple PlantUML processes and evenly schedules the work between them.
 * @template DiagramId The type of the diagram identifier data.
 */
class PlantUmlDiagramGenerator {
    /**
     * Creates a new PlantUML generator object.
     * @param processCount Number of PlantUML processes used to schedule the diagram generation.
     * @param format The format for the generated diagrams.
     * @param imageGeneratedHandler Callback called whenever a diagram has been generated.
     */
    constructor(processCount, format, imageGeneratedHandler) {
        /** The object which encapsulates the PlantUML processes. */
        this.plantUmlProcesses = new Array();
        /** Index of the process that should generate the next diagram. */
        this.nextProcessToGetWorkIndex = 0;
        if (processCount <= 0) {
            throw new Error("processCount must be > 0");
        }
        this.processCount = processCount;
        this.outputFormat = format;
        this.imageGeneratedHandler = imageGeneratedHandler;
    }
    /**
     * Writes the PlantUML code to a PlantUML process that generates the diagram.
     * @param id The identifier for the diagram.
     * @param plantUml The PlantUML code for the diagram.
     */
    generate(id, plantUml) {
        const process = this.getNextProcess();
        process.diagramIdQueue.enqueue(id);
        process.pipe.in.write(plantUml);
    }
    /**
     * Returns an object which encapsulates a PlantUML process that should generate the next diagram.
     * @returns An object for the process that should generate the next diagram.
     */
    getNextProcess() {
        const processToWorkIndex = this.nextProcessToGetWorkIndex;
        this.maybeSpawnNewProcess();
        this.setNextProcessForWork();
        return this.plantUmlProcesses[processToWorkIndex];
    }
    /**
     * If necessary, spawns a new PlantUML process and stores it in the internal process array.
     */
    maybeSpawnNewProcess() {
        if (this.nextProcessToGetWorkIndex >= this.plantUmlProcesses.length) {
            const newPipe = new plantuml_pipe_1.PlantUmlPipe({ outputFormat: this.outputFormat });
            const newQueue = new Queue();
            newPipe.out.on("data", (imageData) => {
                const id = newQueue.dequeue();
                this.imageGeneratedHandler(id, imageData);
            });
            this.plantUmlProcesses.push({ pipe: newPipe, diagramIdQueue: newQueue });
        }
    }
    /**
     * Sets the internal index for the process that should receive the next job.
     */
    setNextProcessForWork() {
        this.nextProcessToGetWorkIndex++;
        if (this.nextProcessToGetWorkIndex === this.processCount) {
            this.nextProcessToGetWorkIndex = 0;
        }
    }
    /**
     * Notifies the PlantUML diagram generator processes that there is no more job to do.
     */
    shutdown() {
        for (const process of this.plantUmlProcesses) {
            process.pipe.in.end();
        }
    }
}
exports.PlantUmlDiagramGenerator = PlantUmlDiagramGenerator;
