"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PluginOptions = exports.ClassDiagramPosition = exports.ImageLocation = void 0;
const typedoc_1 = require("typedoc");
const enumerations_1 = require("./enumerations");
/**
 * Supported image output locations.
 */
var ImageLocation;
(function (ImageLocation) {
    ImageLocation[ImageLocation["Local"] = 1] = "Local";
    ImageLocation[ImageLocation["Remote"] = 2] = "Remote";
    ImageLocation[ImageLocation["Embed"] = 3] = "Embed";
})(ImageLocation = exports.ImageLocation || (exports.ImageLocation = {}));
/**
 * Supported class diagram positions.
 */
var ClassDiagramPosition;
(function (ClassDiagramPosition) {
    ClassDiagramPosition[ClassDiagramPosition["Above"] = 1] = "Above";
    ClassDiagramPosition[ClassDiagramPosition["Below"] = 2] = "Below";
})(ClassDiagramPosition = exports.ClassDiagramPosition || (exports.ClassDiagramPosition = {}));
/**
 * Class storing the options of the plugin.
 */
class PluginOptions {
    constructor() {
        /** Specifies how detailed the class diagrams should be. */
        this.classDiagramTypeOption = {
            type: typedoc_1.ParameterType.Map,
            name: "umlClassDiagramType",
            help: "none|simple|detailed",
            defaultValue: enumerations_1.ClassDiagramType.Detailed,
            map: new Map([
                ["none", enumerations_1.ClassDiagramType.None],
                ["simple", enumerations_1.ClassDiagramType.Simple],
                ["detailed", enumerations_1.ClassDiagramType.Detailed],
            ]),
            value: enumerations_1.ClassDiagramType.Detailed,
        };
        /** The location where the class diagrams should be stored. */
        this.outputImageLocationOption = {
            type: typedoc_1.ParameterType.Map,
            name: "umlClassDiagramLocation",
            help: "local|remote|embed",
            defaultValue: ImageLocation.Local,
            map: new Map([
                ["local", ImageLocation.Local],
                ["remote", ImageLocation.Remote],
                ["embed", ImageLocation.Embed],
            ]),
            value: ImageLocation.Local,
        };
        /** The base URL when generating remote images. */
        this.outputRemoteBaseUrlOption = {
            type: typedoc_1.ParameterType.String,
            name: "umlClassDiagramRemoteBaseUrl",
            help: "The base URL when generating remote images.",
            defaultValue: "http://www.plantuml.com",
            value: "http://www.plantuml.com",
        };
        /** The image format used for the class diagrams. */
        this.outputImageFormatOption = {
            type: typedoc_1.ParameterType.Map,
            name: "umlClassDiagramFormat",
            help: "png|svg",
            defaultValue: "svg" /* SVG */,
            map: new Map([
                ["png", "png" /* PNG */],
                ["svg", "svg" /* SVG */],
            ]),
            value: "svg" /* SVG */,
        };
        /** Specifies the background color used for boxes in the class diagrams. */
        this.sectionTitleOption = {
            type: typedoc_1.ParameterType.String,
            name: "umlClassDiagramSectionTitle",
            help: "The title of the section on the page which includes the class diagram.",
            defaultValue: "Hierarchy-Diagram",
            value: "Hierarchy-Diagram",
        };
        /** Specifies where on the page the class diagram should be put. */
        this.classDiagramPositionOption = {
            type: typedoc_1.ParameterType.Map,
            name: "umlClassDiagramPosition",
            help: "above|below",
            defaultValue: ClassDiagramPosition.Above,
            map: new Map([
                ["above", ClassDiagramPosition.Above],
                ["below", ClassDiagramPosition.Below],
            ]),
            value: ClassDiagramPosition.Above,
        };
        /** Specifies what kind of legend should be added below the class diagrams. */
        this.legendTypeOption = {
            type: typedoc_1.ParameterType.Map,
            name: "umlClassDiagramLegendType",
            help: "none|only-included|full",
            defaultValue: enumerations_1.LegendType.OnlyIncluded,
            map: new Map([
                ["none", enumerations_1.LegendType.None],
                ["only-included", enumerations_1.LegendType.OnlyIncluded],
                ["full", enumerations_1.LegendType.Full],
            ]),
            value: enumerations_1.LegendType.OnlyIncluded,
        };
        /** Specifies how method parameters should be output in the class diagrams. */
        this.classDiagramMethodParameterOutputOption = {
            type: typedoc_1.ParameterType.Map,
            name: "umlClassDiagramMethodParameterOutput",
            help: "none|only-names|only-types|complete",
            defaultValue: enumerations_1.MethodParameterOutput.Complete,
            map: new Map([
                ["none", enumerations_1.MethodParameterOutput.None],
                ["only-names", enumerations_1.MethodParameterOutput.OnlyNames],
                ["only-types", enumerations_1.MethodParameterOutput.OnlyTypes],
                ["complete", enumerations_1.MethodParameterOutput.Complete],
            ]),
            value: enumerations_1.MethodParameterOutput.Complete,
        };
        /** Specifies how class members should be ordered in the class diagrams. */
        this.classDiagramMemberOrderOption = {
            type: typedoc_1.ParameterType.Map,
            name: "umlClassDiagramMemberOrder",
            help: "abc|public-to-private|private-to-public",
            defaultValue: enumerations_1.MemberOrder.PublicToPrivate,
            map: new Map([
                ["abc", enumerations_1.MemberOrder.Abc],
                ["public-to-private", enumerations_1.MemberOrder.PublicToPrivate],
                ["private-to-public", enumerations_1.MemberOrder.PrivateToPublic],
            ]),
            value: enumerations_1.MemberOrder.PublicToPrivate,
        };
        /** Specifies whether to hide empty properties and methods in the class diagrams. */
        this.classDiagramHideEmptyMembersOption = {
            type: typedoc_1.ParameterType.Boolean,
            name: "umlClassDiagramHideEmptyMembers",
            help: "true|false",
            defaultValue: true,
            value: true,
        };
        /** Specifies the boundary before swiching from top->down to left->right direction for class diagrams. */
        this.classDiagramTopDownLayoutMaxSiblingsOption = {
            type: typedoc_1.ParameterType.Number,
            name: "umlClassDiagramTopDownLayoutMaxSiblings",
            help: "An integer indicating the max number of siblings to be used with the default top down layout.",
            defaultValue: 6,
            minValue: 0,
            value: 6,
        };
        /** Specifies how the visibility of members should be displayed in the class diagrams. */
        this.classDiagramMemberVisibilityStyleOption = {
            type: typedoc_1.ParameterType.Map,
            name: "umlClassDiagramMemberVisibilityStyle",
            help: "text|icon",
            defaultValue: "icon" /* Icon */,
            map: new Map([
                ["text", "text" /* Text */],
                ["icon", "icon" /* Icon */],
            ]),
            value: "icon" /* Icon */,
        };
        /**
         * Specifies whether to hide the circled character in front of class names in the class diagrams.
         */
        this.classDiagramHideCircledCharOption = {
            type: typedoc_1.ParameterType.Boolean,
            name: "umlClassDiagramHideCircledChar",
            help: "true|false",
            defaultValue: false,
            value: false,
        };
        /** Specifies whether to hide the shadowing in the class diagrams. */
        this.classDiagramHideShadowOption = {
            type: typedoc_1.ParameterType.Boolean,
            name: "umlClassDiagramHideShadow",
            help: "true|false",
            defaultValue: false,
            value: false,
        };
        /** Specifies the background color used for boxes in the class diagrams. */
        this.classDiagramBoxBackgroundColorOption = {
            type: typedoc_1.ParameterType.String,
            name: "umlClassDiagramBoxBackgroundColor",
            help: "transparent|#RGBHEX",
            defaultValue: "",
            value: "",
        };
        /** Specifies the border color used for boxes in the class diagrams. */
        this.classDiagramBoxBorderColorOption = {
            type: typedoc_1.ParameterType.String,
            name: "umlClassDiagramBoxBorderColor",
            help: "transparent|#RGBHEX",
            defaultValue: "",
            value: "",
        };
        /** Specifies the border radius used for boxes in the class diagrams. */
        this.classDiagramBoxBorderRadiusOption = {
            type: typedoc_1.ParameterType.Number,
            name: "umlClassDiagramBoxBorderRadius",
            help: "The box border radius in pixel used for the class diagrams.",
            defaultValue: 0,
            minValue: 0,
            value: 0,
        };
        /** Specifies the border width used for boxes in the class diagrams. */
        this.classDiagramBoxBorderWidthOption = {
            type: typedoc_1.ParameterType.Number,
            name: "umlClassDiagramBoxBorderWidth",
            help: "The box border width in pixel used for the class diagrams.",
            defaultValue: -1,
            minValue: 0,
            value: -1,
        };
        /** Specifies the color used for arrows in the class diagrams. */
        this.classDiagramArrowColorOption = {
            type: typedoc_1.ParameterType.String,
            name: "umlClassDiagramArrowColor",
            help: "transparent|#RGBHEX",
            defaultValue: "",
            value: "",
        };
        /** Specifies the name of the font used for the class name in the class diagrams. */
        this.classDiagramClassFontNameOption = {
            type: typedoc_1.ParameterType.String,
            name: "umlClassDiagramClassFontName",
            help: "The name of the font used for the class name in the class diagrams.",
            defaultValue: "",
            value: "",
        };
        /** Specifies the font size for the class name in the class diagrams. */
        this.classDiagramClassFontSizeOption = {
            type: typedoc_1.ParameterType.Number,
            name: "umlClassDiagramClassFontSize",
            help: "The font size in pixel used for the class name in the class diagrams.",
            defaultValue: 0,
            minValue: 0,
            value: 0,
        };
        /** Specifies the font style for the class name in the class diagrams. */
        this.classDiagramClassFontStyleOption = {
            type: typedoc_1.ParameterType.Map,
            name: "umlClassDiagramClassFontStyle",
            help: "normal|plain|italic|bold",
            defaultValue: "" /* Default */,
            map: new Map([
                ["normal", "normal" /* Normal */],
                ["plain", "plain" /* Plain */],
                ["italic", "italic" /* Italic */],
                ["bold", "bold" /* Bold */],
            ]),
            value: "" /* Default */,
        };
        /** Specifies the font color for the class name in the class diagrams. */
        this.classDiagramClassFontColorOption = {
            type: typedoc_1.ParameterType.String,
            name: "umlClassDiagramClassFontColor",
            help: "transparent|#RGBHEX",
            defaultValue: "",
            value: "",
        };
        /** Specifies the name of the font used for the class attributes in the class diagrams. */
        this.classDiagramClassAttributeFontNameOption = {
            type: typedoc_1.ParameterType.String,
            name: "umlClassDiagramClassAttributeFontName",
            help: "The name of the font used for the class attributes in the class diagrams.",
            defaultValue: "",
            value: "",
        };
        /** Specifies the font size for the class attributes in the class diagrams. */
        this.classDiagramClassAttributeFontSizeOption = {
            type: typedoc_1.ParameterType.Number,
            name: "umlClassDiagramClassAttributeFontSize",
            help: "The font size in pixel used for the class attributes in the class diagrams.",
            defaultValue: 0,
            minValue: 0,
            value: 0,
        };
        /** Specifies the font style for the class attributes in the class diagrams. */
        this.classDiagramClassAttributeFontStyleOption = {
            type: typedoc_1.ParameterType.Map,
            name: "umlClassDiagramClassAttributeFontStyle",
            help: "normal|plain|italic|bold",
            defaultValue: "" /* Default */,
            map: new Map([
                ["normal", "normal" /* Normal */],
                ["plain", "plain" /* Plain */],
                ["italic", "italic" /* Italic */],
                ["bold", "bold" /* Bold */],
            ]),
            value: "" /* Default */,
        };
        /** Specifies the font color for the class attributes in the class diagrams. */
        this.classDiagramClassAttributeFontColorOption = {
            type: typedoc_1.ParameterType.String,
            name: "umlClassDiagramClassAttributeFontColor",
            help: "transparent|#RGBHEX",
            defaultValue: "",
            value: "",
        };
        /** Specifies how many PlantUML processes should be used for generating the class diagrams. */
        this.generatorProcessCountOption = {
            type: typedoc_1.ParameterType.Number,
            name: "umlClassDiagramGeneratorProcessCount",
            help: "The number of PlantUML processes used for generating the class diagrams.",
            defaultValue: 1,
            minValue: 1,
            value: 1,
        };
        /** Specifies whether to hide the progress bar while generating diagrams. */
        this.hideProgressBarOption = {
            type: typedoc_1.ParameterType.Boolean,
            name: "umlClassDiagramHideProgressBar",
            help: "true|false",
            defaultValue: false,
            value: false,
        };
        /** Specifies whether to create files containing the PlantUML code of the class diagrams. */
        this.createPlantUmlFilesOption = {
            type: typedoc_1.ParameterType.Boolean,
            name: "umlClassDiagramCreatePlantUmlFiles",
            help: "true|false",
            defaultValue: false,
            value: false,
        };
        /** Specifies whether the plugin should output verbose info during its work. */
        this.createVerboseOutputOption = {
            type: typedoc_1.ParameterType.Boolean,
            name: "umlClassDiagramVerboseOutput",
            help: "true|false",
            defaultValue: false,
            value: false,
        };
    }
    /**
     * Adds the command line options of the plugin to the TypeDoc application.
     * @param typedoc The TypeDoc application.
     */
    // prettier-ignore
    /* eslint-disable max-len */
    addToApplication(typedoc) {
        typedoc.options.addDeclaration(this.classDiagramTypeOption);
        typedoc.options.addDeclaration(this.outputImageLocationOption);
        typedoc.options.addDeclaration(this.outputRemoteBaseUrlOption);
        typedoc.options.addDeclaration(this.outputImageFormatOption);
        typedoc.options.addDeclaration(this.sectionTitleOption);
        typedoc.options.addDeclaration(this.classDiagramPositionOption);
        typedoc.options.addDeclaration(this.legendTypeOption);
        typedoc.options.addDeclaration(this.classDiagramMethodParameterOutputOption);
        typedoc.options.addDeclaration(this.classDiagramMemberOrderOption);
        typedoc.options.addDeclaration(this.classDiagramHideEmptyMembersOption);
        typedoc.options.addDeclaration(this.classDiagramTopDownLayoutMaxSiblingsOption);
        typedoc.options.addDeclaration(this.classDiagramMemberVisibilityStyleOption);
        typedoc.options.addDeclaration(this.classDiagramHideCircledCharOption);
        typedoc.options.addDeclaration(this.classDiagramHideShadowOption);
        typedoc.options.addDeclaration(this.classDiagramBoxBackgroundColorOption);
        typedoc.options.addDeclaration(this.classDiagramBoxBorderColorOption);
        typedoc.options.addDeclaration(this.classDiagramBoxBorderRadiusOption);
        typedoc.options.addDeclaration(this.classDiagramBoxBorderWidthOption);
        typedoc.options.addDeclaration(this.classDiagramArrowColorOption);
        typedoc.options.addDeclaration(this.classDiagramClassFontNameOption);
        typedoc.options.addDeclaration(this.classDiagramClassFontSizeOption);
        typedoc.options.addDeclaration(this.classDiagramClassFontStyleOption);
        typedoc.options.addDeclaration(this.classDiagramClassFontColorOption);
        typedoc.options.addDeclaration(this.classDiagramClassAttributeFontNameOption);
        typedoc.options.addDeclaration(this.classDiagramClassAttributeFontSizeOption);
        typedoc.options.addDeclaration(this.classDiagramClassAttributeFontStyleOption);
        typedoc.options.addDeclaration(this.classDiagramClassAttributeFontColorOption);
        typedoc.options.addDeclaration(this.generatorProcessCountOption);
        typedoc.options.addDeclaration(this.hideProgressBarOption);
        typedoc.options.addDeclaration(this.createPlantUmlFilesOption);
        typedoc.options.addDeclaration(this.createVerboseOutputOption);
    }
    /* eslint-enable max-len */
    /**
     * Reads the values of the plugin options from the application options.
     * @param appOptions The TypeDoc application.
     */
    // prettier-ignore
    /* eslint-disable max-len */
    readValuesFromApplication(typedoc) {
        this.classDiagramTypeOption.value = typedoc.options.getValue(this.classDiagramTypeOption.name);
        this.outputImageLocationOption.value = typedoc.options.getValue(this.outputImageLocationOption.name);
        this.outputRemoteBaseUrlOption.value = typedoc.options.getValue(this.outputRemoteBaseUrlOption.name);
        this.outputImageFormatOption.value = typedoc.options.getValue(this.outputImageFormatOption.name);
        this.sectionTitleOption.value = typedoc.options.getValue(this.sectionTitleOption.name);
        this.classDiagramPositionOption.value = typedoc.options.getValue(this.classDiagramPositionOption.name);
        this.legendTypeOption.value = typedoc.options.getValue(this.legendTypeOption.name);
        this.classDiagramMethodParameterOutputOption.value = typedoc.options.getValue(this.classDiagramMethodParameterOutputOption.name);
        this.classDiagramMemberOrderOption.value = typedoc.options.getValue(this.classDiagramMemberOrderOption.name);
        this.classDiagramHideEmptyMembersOption.value = typedoc.options.getValue(this.classDiagramHideEmptyMembersOption.name);
        this.classDiagramTopDownLayoutMaxSiblingsOption.value = typedoc.options.getValue(this.classDiagramTopDownLayoutMaxSiblingsOption.name);
        this.classDiagramMemberVisibilityStyleOption.value = typedoc.options.getValue(this.classDiagramMemberVisibilityStyleOption.name);
        this.classDiagramHideCircledCharOption.value = typedoc.options.getValue(this.classDiagramHideCircledCharOption.name);
        this.classDiagramHideShadowOption.value = typedoc.options.getValue(this.classDiagramHideShadowOption.name);
        this.classDiagramBoxBackgroundColorOption.value = typedoc.options.getValue(this.classDiagramBoxBackgroundColorOption.name);
        this.classDiagramBoxBorderColorOption.value = typedoc.options.getValue(this.classDiagramBoxBorderColorOption.name);
        this.classDiagramBoxBorderRadiusOption.value = typedoc.options.getValue(this.classDiagramBoxBorderRadiusOption.name);
        this.classDiagramBoxBorderWidthOption.value = typedoc.options.getValue(this.classDiagramBoxBorderWidthOption.name);
        this.classDiagramArrowColorOption.value = typedoc.options.getValue(this.classDiagramArrowColorOption.name);
        this.classDiagramClassFontNameOption.value = typedoc.options.getValue(this.classDiagramClassFontNameOption.name);
        this.classDiagramClassFontSizeOption.value = typedoc.options.getValue(this.classDiagramClassFontSizeOption.name);
        this.classDiagramClassFontStyleOption.value = typedoc.options.getValue(this.classDiagramClassFontStyleOption.name);
        this.classDiagramClassFontColorOption.value = typedoc.options.getValue(this.classDiagramClassFontColorOption.name);
        this.classDiagramClassAttributeFontNameOption.value = typedoc.options.getValue(this.classDiagramClassAttributeFontNameOption.name);
        this.classDiagramClassAttributeFontSizeOption.value = typedoc.options.getValue(this.classDiagramClassAttributeFontSizeOption.name);
        this.classDiagramClassAttributeFontStyleOption.value = typedoc.options.getValue(this.classDiagramClassAttributeFontStyleOption.name);
        this.classDiagramClassAttributeFontColorOption.value = typedoc.options.getValue(this.classDiagramClassAttributeFontColorOption.name);
        this.generatorProcessCountOption.value = typedoc.options.getValue(this.generatorProcessCountOption.name);
        this.hideProgressBarOption.value = typedoc.options.getValue(this.hideProgressBarOption.name);
        this.createPlantUmlFilesOption.value = typedoc.options.getValue(this.createPlantUmlFilesOption.name);
        this.createVerboseOutputOption.value = typedoc.options.getValue(this.createVerboseOutputOption.name);
    }
    /* eslint-enable max-len */
    /**
     * Returns how detailed the generated class diagrams should be.
     * @returns How detailed the generated class diagrams should be.
     */
    get classDiagramType() {
        return this.classDiagramTypeOption.value;
    }
    /**
     * Returns the location where the class diagrams should be stored.
     * @returns The location where the class diagrams should be stored.
     */
    get outputImageLocation() {
        return this.outputImageLocationOption.value;
    }
    /**
     * Returns the base URL used when generating remote images.
     * @returns The base URL used when generating remote images.
     */
    get outputRemoteBaseUrl() {
        return this.outputRemoteBaseUrlOption.value;
    }
    /**
     * Returns the image format used for the class diagrams.
     * @returns The image format used for the class diagrams.
     */
    get outputImageFormat() {
        return this.outputImageFormatOption.value;
    }
    /**
     * Returns the title that should be used for the section that contains the class diagrams.
     * @returns The title that should be used for the section that contains the class diagrams.
     */
    get sectionTitle() {
        return this.sectionTitleOption.value;
    }
    /**
     * Returns where on the page the class diagrams should be put.
     * @returns Where on the page the class diagrams should be put.
     */
    get classDiagramPosition() {
        return this.classDiagramPositionOption.value;
    }
    /**
     * Returns the type of legend that should be generated for the class diagrams.
     * @returns The type of legend that should be generated for the class diagrams.
     */
    get legendType() {
        return this.legendTypeOption.value;
    }
    /**
     * Returns how method parameters should be output in the class diagrams.
     * @returns How method parameters should be output in the class diagrams.
     */
    get classDiagramMethodParameterOutput() {
        return this.classDiagramMethodParameterOutputOption.value;
    }
    /**
     * Returns how class members should be ordered in the class diagrams.
     * @returns How class members should be ordered the class diagrams.
     */
    get classDiagramMemberOrder() {
        return this.classDiagramMemberOrderOption.value;
    }
    /**
     * Returns whether to hide empty properties and methods in the class diagrams.
     * @returns Whether to hide empty properties and methods in the class diagrams.
     */
    get classDiagramHideEmptyMembers() {
        return this.classDiagramHideEmptyMembersOption.value;
    }
    /**
     * Returns the boundary before swiching from top->down to left->right direction for class diagrams.
     * @returns The boundary before swiching from top->down to left->right direction for class diagrams.
     */
    get classDiagramTopDownLayoutMaxSiblings() {
        return this.classDiagramTopDownLayoutMaxSiblingsOption.value;
    }
    /**
     * Returns how the member visibility is rendered in the class diagrams.
     * @returns How the member visibility is rendered in the class diagrams.
     */
    get classDiagramMemberVisibilityStyle() {
        return this.classDiagramMemberVisibilityStyleOption.value;
    }
    /**
     * Returns whether to hide the circled character in front of class names for class diagrams.
     * @returns Whether to hide the circled character in front of class names for class diagrams.
     */
    get classDiagramHideCircledChar() {
        return this.classDiagramHideCircledCharOption.value;
    }
    /**
     * Returns whether to hide the shadows in the class diagrams.
     * @returns Whether to hide the shadows in the class diagrams.
     */
    get classDiagramHideShadow() {
        return this.classDiagramHideShadowOption.value;
    }
    /**
     * Returns the background color that should be used for boxes in the class diagrams.
     * @returns The background color that should be used for boxes in the class diagrams.
     *          An empty string if no value was specified by the caller.
     *          In this case the PlantUML default value should be used.
     */
    get classDiagramBoxBackgroundColor() {
        return this.classDiagramBoxBackgroundColorOption.value;
    }
    /**
     * Returns the border color that should be used for boxes in the class diagrams.
     * @returns The border color that should be used for boxes in the class diagrams.
     *          An empty string if no value was specified by the caller.
     *          In this case the PlantUML default value should be used.
     */
    get classDiagramBoxBorderColor() {
        return this.classDiagramBoxBorderColorOption.value;
    }
    /**
     * Returns the border radius that should be used for boxes in the class diagrams.
     * @returns The border radius that should be used for boxes in the class diagrams.
     */
    get classDiagramBoxBorderRadius() {
        return this.classDiagramBoxBorderRadiusOption.value;
    }
    /**
     * Returns the border width that should be used for boxes in the class diagrams.
     * @returns The border width that should be used for boxes in the class diagrams.
     *          The value -1 if no value was specified by the caller.
     *          In this case the PlantUML default value should be used.
     */
    get classDiagramBoxBorderWidth() {
        return this.classDiagramBoxBorderWidthOption.value;
    }
    /**
     * Returns the color that should be used for arrows in the class diagrams.
     * @returns The color that should be used for arrows in the class diagrams.
     *          An empty string if no value was specified by the caller.
     *          In this case the PlantUML default value should be used.
     */
    get classDiagramArrowColor() {
        return this.classDiagramArrowColorOption.value;
    }
    /**
     * Returns the name of the font that should be used for the class name in the class diagrams.
     * @returns The name of the font that should be used for the class name in the class diagrams.
     *          An empty string if no value was specified by the caller.
     *          In this case the PlantUML default value should be used.
     */
    get classDiagramClassFontName() {
        return this.classDiagramClassFontNameOption.value;
    }
    /**
     * Returns the font size that should be used for class names in the class diagrams.
     * @returns The font size that should be used for class names in the class diagrams.
     *          The value 0 if no value was specified by the caller.
     *          In this case the PlantUML default value should be used.
     */
    get classDiagramClassFontSize() {
        return this.classDiagramClassFontSizeOption.value;
    }
    /**
     * Returns the font style that should be used for the class name in the class diagrams.
     * @returns The font style that should be used for the class name in the class diagrams.
     */
    get classDiagramClassFontStyle() {
        return this.classDiagramClassFontStyleOption.value;
    }
    /**
     * Returns the font color that should be used for the class name in the class diagrams.
     * @returns The font color that should be used for the class name in the class diagrams.
     *          An empty string if no value was specified by the caller.
     *          In this case the PlantUML default value should be used.
     */
    get classDiagramClassFontColor() {
        return this.classDiagramClassFontColorOption.value;
    }
    /**
     * Returns the name of the font that should be used for class attributes in the class diagrams.
     * @returns The name of the font that should be used for class attributes in the class diagrams.
     *          An empty string if no value was specified by the caller.
     *          In this case the PlantUML default value should be used.
     */
    get classDiagramClassAttributeFontName() {
        return this.classDiagramClassAttributeFontNameOption.value;
    }
    /**
     * Returns the font size that should be used for class attributes in the class diagrams.
     * @returns The font size that should be used for class attributes in the class diagrams.
     *          The value 0 if no value was specified by the caller.
     *          In this case the PlantUML default value should be used.
     */
    get classDiagramClassAttributeFontSize() {
        return this.classDiagramClassAttributeFontSizeOption.value;
    }
    /**
     * Returns the font style that should be used for the class attributes in the class diagrams.
     * @returns The font style that should be used for the class attributes in the class diagrams.
     */
    get classDiagramClassAttributeFontStyle() {
        return this.classDiagramClassAttributeFontStyleOption.value;
    }
    /**
     * Returns the font color that should be used for the class attributes in the class diagrams.
     * @returns The font color that should be used for the class attributes in the class diagrams.
     *          An empty string if no value was specified by the caller.
     *          In this case the PlantUML default value should be used.
     */
    get classDiagramClassAttributeFontColor() {
        return this.classDiagramClassAttributeFontColorOption.value;
    }
    /**
     * Returns the number of PlantUML processes that should be used for generating the class diagrams.
     * @returns The number of PlantUML processes that should be used for generating the class diagrams.
     */
    get generatorProcessCount() {
        return this.generatorProcessCountOption.value;
    }
    /**
     * Returns whether to hide the progress bar while generating the class diagrams.
     * @returns True, if the progress bar should not be displayed while generating the class diagrams, otherwise false.
     */
    get hideProgressBar() {
        return this.hideProgressBarOption.value;
    }
    /**
     * Returns whether to create files containing the PlantUML code for the class diagrams.
     * @returns True, if files with the PlantUML code should be created, otherwise false.
     */
    get createPlantUmlFiles() {
        return this.createPlantUmlFilesOption.value;
    }
    /**
     * Returns whether the plugin should output verbose info during its work.
     * @returns True, if plugin should create verbose output, otherwise false.
     */
    get createVerboseOutput() {
        return this.createVerboseOutputOption.value;
    }
}
exports.PluginOptions = PluginOptions;
