"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PageSectionFinder = void 0;
/**
 * Helper class for finding sections on a TypeDoc page.
 */
class PageSectionFinder {
    /**
     * Checks if there is a given section in the content.
     * @param content The content in which to look for the section.
     * @param section The section that is looked for.
     * @returns True, if the section is found in the content, otherwise false.
     */
    static hasSection(content, section) {
        const location = PageSectionFinder.getSectionLocation(content, section);
        return location.startIndex !== location.endIndex;
    }
    /**
     * Returns the position of the section within the content.
     * @param content The content in which to look for the section.
     * @param section The section whos location is wanted.
     * @returns An object with the start and end index of the section.
     *          If the section cannot be found in the content both startIndex and endIndex equal 0.
     */
    static getSectionLocation(content, section) {
        const regex = PageSectionFinder.getLookUpRegexpForSection(section);
        const match = regex.exec(content);
        return match
            ? { startIndex: match.index, endIndex: match.index + match[0].length }
            : { startIndex: 0, endIndex: 0 };
    }
    /**
     * Returns a regular expression that can be used to match a section.
     * @param section The section to match.
     * @returns The regular expression to match the section.
     */
    static getLookUpRegexpForSection(section) {
        if (!PageSectionFinder.pageSectionLookUpCache.has(section)) {
            PageSectionFinder.pageSectionLookUpCache.set(section, PageSectionFinder.createLookUpRegexpForSection(section));
        }
        return PageSectionFinder.pageSectionLookUpCache.get(section);
    }
    /**
     * Creates a regular expression that can be used to match a section with a given name.
     * @param sectionName The name of the section.
     * @returns The regular expression to match the section.
     */
    static createLookUpRegexpForSection(sectionName) {
        return new RegExp('<section class="tsd-panel[^"<>]*?">\\s*<h3>' + sectionName + "</h3>[^]*?</section>");
    }
}
exports.PageSectionFinder = PageSectionFinder;
/** Map for caching regular expressions to find a section on a page. */
PageSectionFinder.pageSectionLookUpCache = new Map();
